Muffin-Redis-Cache
##################

.. _description:

Adds easy cache support with Redis to Muffin project.

.. _badges:

.. image:: http://img.shields.io/travis/klinkin/muffin-redis-cache.svg?style=flat-square
    :target: http://travis-ci.org/klinkin/muffin-redis-cache
    :alt: Build Status

.. image:: http://img.shields.io/coveralls/klinkin/muffin-redis-cache.svg?style=flat-square
    :target: https://coveralls.io/r/klinkin/muffin-redis-cache
    :alt: Coverals

.. image:: http://img.shields.io/pypi/v/muffin-redis-cache.svg?style=flat-square
    :target: https://pypi.python.org/pypi/muffin-redis-cache

.. image:: http://img.shields.io/pypi/dm/muffin-redis-cache.svg?style=flat-square
    :target: https://pypi.python.org/pypi/muffin-redis-cache

.. image:: http://img.shields.io/gratipay/klinkin.svg?style=flat-square
    :target: https://www.gratipay.com/klinkin/
    :alt: Donate

.. _documentation:

**Docs are available at https://muffin-redis-cache.readthedocs.org/. Pull requests
with documentation enhancements and/or fixes are awesome and most welcome.**

.. _contents:

.. contents::

.. _requirements:

Requirements
=============

- python >= 3.4

.. _installation:

Installation
=============

**Muffin-Redis-Cache** should be installed using pip:

.. code-block:: python

    pip install muffin-redis-cache

.. _usage:

Usage
=====

.. _bugtracker:

Bug tracker
===========

If you have any suggestions, bug reports or
annoyances please report them to the issue tracker
at https://github.com/klinkin/muffin-redis-cache/issues

.. _contributing:

Contributing
============

Development of Muffin-Redis-Cache happens at: https://github.com/klinkin/muffin-redis-cache


Contributors
=============

* klinkin_ (Mike Klimin)

.. _license:

License
=======

Licensed under a `MIT license`_.

.. _links:


.. _klinkin: https://github.com/klinkin

.. _MIT license: http://opensource.org/licenses/MIT
